@@ -43,7 +43,7 @@ from eolie.menu_pages import PagesMenu
 from eolie.helper_dbus import DBusHelper
 from eolie.helper_task import TaskHelper
 from eolie.define import EOLIE_DATA_PATH, TimeSpan, TimeSpanValues, LoadingType
-from eolie.utils import is_unity, wanted_loading_type, set_proxy_from_gnome
+from eolie.utils import is_unity, wanted_loading_type
 from eolie.logger import Logger
 
 
@@ -68,7 +68,6 @@ class Application(Gtk.Application):
         # We force it to current python 3.6 name, to be sure in case of
         # change in python
         current_thread().setName("MainThread")
-        set_proxy_from_gnome()
         # First check WebKit2 version
         if WebKit2.MINOR_VERSION < 18:
             exit("You need WebKit2GTK >= 2.18")
@@ -540,6 +539,7 @@ class Application(Gtk.Application):
                 if state is not None:
                     session_states.append(state)
         window_state["states"] = session_states
+        window_state["sites"] = window.container.sites_manager.sort
         return window_state
 
     def __save_state(self):
@@ -576,27 +576,34 @@ class Application(Gtk.Application):
         size = (800, 600)
         maximized = False
         try:
-            windows = load(open(EOLIE_DATA_PATH + "/session_states.bin", "rb"))
+            window_states = load(
+                open(EOLIE_DATA_PATH + "/session_states.bin", "rb"))
             if self.settings.get_value("remember-session"):
-                for window in windows:
-                    if not window["states"]:
-                        continue
-                    new_window = self.get_new_window(window["size"],
-                                                     window["maximized"])
+                for window_state in window_states:
+                    window = self.get_new_window(window_state["size"],
+                                                 window_state["maximized"])
+                    window.container.sites_manager.set_initial_sort(
+                        window_state["sites"])
                     items = []
                     i = 0 if foreground else 1
                     for (uri, title, atime,
-                         ephemeral, state) in window["states"]:
+                         ephemeral, state) in window_state["states"]:
                         loading_type = wanted_loading_type(i)
                         webkit_state = WebKit2.WebViewSessionState(
                             GLib.Bytes.new(state))
                         items.append((uri, title, atime, ephemeral,
                                       webkit_state, loading_type))
                         i += 1
-                    new_window.container.add_webviews(items)
-            elif windows:
-                size = windows[0]["size"]
-                maximized = windows[0]["maximized"]
+                    if window_state["states"]:
+                        window.container.add_webviews(items)
+                    else:
+                        window.container.add_webview(
+                            self.start_page,
+                            LoadingType.FOREGROUND,
+                            False)
+            elif window_states:
+                size = window_states[0]["size"]
+                maximized = window_states[0]["maximized"]
         except Exception as e:
             Logger.error("Application::__create_initial_windows(): %s", e)
         if not self.get_windows():
